@@ -17,7 +17,8 @@ from connectionmanager import ConnectionManager
 
 class DropN900(QtCore.QObject):
 
-    def __init__(self, debug_enabled = False):
+    def __init__(self, debug_enabled = False, maemo_env = True):
+        self.set_abs_path(maemo_env)
         self.ui = UiController(self, debug_enabled)
         self.connection = ConnectionManager(self, self.ui)
         self.ui.tree_controller.set_connection(self.connection)
@@ -26,7 +27,7 @@ class DropN900(QtCore.QObject):
         self.ui.show()
         self.reset_variables()
         self.check_for_data_folder()
-        self.check_for_auth(".token")
+        self.check_for_auth(self.abs_path(".token"))
 
     def reset_variables(self):
         self.authenticator = None
@@ -63,13 +64,13 @@ class DropN900(QtCore.QObject):
         token_config.set("token", "secret", access_token.secret)
         token_config.set("token", "key", access_token.key)
         
-        write_file = open(".token", "w")
+        write_file = open(self.abs_path(".token"), "w")
         token_config.write(write_file)
         write_file.close()
 
     def reset_auth(self):
         try:
-            os.remove(".token")
+            os.remove(self.abs_path(".token"))
         except OSError:
             pass
         self.start_trusted_auth()
@@ -136,7 +137,7 @@ class DropN900(QtCore.QObject):
         self.connected = True
 
     def get_config(self):
-        return auth.Authenticator.load_config(".config")
+        return auth.Authenticator.load_config(self.abs_path(".config"))
     
     def log(self, msg, param = None):
         if param is None:
@@ -144,12 +145,23 @@ class DropN900(QtCore.QObject):
         else:
             msg_join = msg + " %s" % param
             self.ui.log(msg_join)       
-
+    
+    def set_abs_path(self, maemo_env):
+        if maemo_env:
+            self.app_root = "/opt/dropn900/"
+        else:
+            self.app_root = ""
+            
+    def abs_path(self, rel_path):
+        return self.app_root + rel_path
+        
 """ This is the main function that starts the program """
 
 if __name__ == "__main__":
     app = QtGui.QApplication(sys.argv)
-    dropn900 = DropN900(False) # Debug mode
+    debug = False
+    maemo_env = True
+    dropn900 = DropN900(debug, maemo_env)
     dropn900.start()
     os._exit(app.exec_())
 
